Skip to contents

Computes the mean direction vector and mean spherical coordinates.

Usage

spherical_summary(
  theta,
  phi,
  weights = NULL,
  convention = c("azimuth_colatitude", "azimuth_elevation"),
  na.rm = TRUE
)

Arguments

theta

Azimuth angle in radians.

phi

Colatitude or elevation angle in radians.

weights

Optional non-negative weights.

convention

Interpretation of phi.

na.rm

Should missing values be removed?

Value

A tibble with sample size, mean spherical coordinates and resultant length.

See also