Draws angular intervals as arcs at a fixed radius. Intervals crossing zero are split into two path segments.
Usage
geom_confidence_arc(
mapping = NULL,
data = NULL,
...,
radius = 1,
n = 200,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_circular_interval(
mapping = NULL,
data = NULL,
...,
radius = 1,
n = 200,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)Arguments
- mapping, data, show.legend, inherit.aes
Standard ggplot2 layer arguments.
- ...
Additional arguments passed to the path geometry.
- radius
Default radius used when no
radiusoryaesthetic is supplied.- n
Number of points used to discretize each interval.
- na.rm
Should missing interval endpoints be silently removed?