Computes the sample mean direction. For axial data, angles are doubled before computing the mean and the result is transformed back to the axial scale.
See also
Other circular summaries:
circular_mean_ci(),
circular_sd(),
circular_summary(),
circular_variance(),
estimate_kappa(),
mean_resultant_length(),
resultant_length()
Examples
mean_direction(c(0, pi / 4, pi / 2))
#> [1] 0.7853982